Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1316)

Unified Diff: Source/core/layout/style/CachedUAStyle.h

Issue 1033943002: Rename LayoutStyle to papayawhip (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: ensureComputedStyle Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/layout/style/BorderValue.h ('k') | Source/core/layout/style/ComputedStyle.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/layout/style/CachedUAStyle.h
diff --git a/Source/core/layout/style/CachedUAStyle.h b/Source/core/layout/style/CachedUAStyle.h
index 84facb620f6fb1dc59c5afa8d84a1b8dce56d0d4..4d30ae2bf36955962c620aa32c6c3c53a0a47134 100644
--- a/Source/core/layout/style/CachedUAStyle.h
+++ b/Source/core/layout/style/CachedUAStyle.h
@@ -22,17 +22,17 @@
#ifndef CachedUAStyle_h
#define CachedUAStyle_h
-#include "core/layout/style/LayoutStyle.h"
+#include "core/layout/style/ComputedStyle.h"
namespace blink {
// LayoutTheme::adjustStyle wants the background and borders
// as specified by the UA sheets, excluding any author rules.
// We use this class to cache those values during
// applyMatchedProperties for later use during adjustLayoutStyle.
class CachedUAStyle {
public:
- static PassOwnPtr<CachedUAStyle> create(const LayoutStyle* style)
+ static PassOwnPtr<CachedUAStyle> create(const ComputedStyle* style)
{
return adoptPtr(new CachedUAStyle(style));
}
@@ -42,7 +42,7 @@ public:
StyleColor backgroundColor;
private:
- explicit CachedUAStyle(const LayoutStyle* style)
+ explicit CachedUAStyle(const ComputedStyle* style)
: border(style->border())
, backgroundLayers(style->backgroundLayers())
, backgroundColor(style->backgroundColor())
@@ -22,17 +22,17 @@
// as specified by the UA sheets, excluding any author rules.
// We use this class to cache those values during
-// applyMatchedProperties for later use during adjustLayoutStyle.
+// applyMatchedProperties for later use during adjustComputedStyle.
class CachedUAStyle {
public:
« no previous file with comments | « Source/core/layout/style/BorderValue.h ('k') | Source/core/layout/style/ComputedStyle.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698